TargetError

Enum TargetError 

#[non_exhaustive]
pub enum TargetError { UnsetHome { location: Location, }, UnsetOldpwd { location: Location, }, NonExistingDirectory { missing: PathBuf, target: PathBuf, location: Location, }, }
Error in computing the target directory

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnsetHome

The operand is omitted, but $HOME is not set or is empty.

Fields

location: Location

Location in the source code where the cd built-in is called



UnsetOldpwd

The operand is -, but $OLDPWD is not set or is empty.

Fields

location: Location

Location of the - operand



NonExistingDirectory

Non-existing directory

When the -L option is specified, the built-in tries to canonicalize path a/b/../c to a/c. This is only possible if a/b exists. This error is returned when a/b is not a directory.

Fields

missing: PathBuf

Path to the non-existing directory

target: PathBuf

Entire path to the target directory

location: Location

Location in the source code where the target directory is specified

Implementations

Source

impl TargetError

pub fn exit_status(&self) -> ExitStatus

Returns the exit status that corresponds to this error.

pub fn to_report(&self) -> Report<'_>

Converts this error to a Report.