Categorization

Enum Categorization 

pub enum Categorization<S> {
    Keyword,
    Alias(Rc<Alias>),
    Target(Target<S>),
}
Result of categorizing a command

Notes on equality

Although this type implements PartialEq, comparison between instances of this type may not always yield predictable results due to the presence of function pointers in Target. As a result, it is recommended to avoid relying on equality comparisons for values of this type. See https://doc.rust-lang.org/std/ptr/fn.fn_addr_eq.html for the characteristics of function pointer comparisons.

Variants



Keyword

Shell reserved word



Alias(Rc<Alias>)

Alias



Target(Target<S>)

Target program that can be executed