Identify

Struct Identify 

pub struct Identify {
    pub names: Vec<Field>,
    pub search: Search,
    pub verbose: bool,
}
Parameters to identify a utility

Fields

names: Vec<Field>

Command names

search: Search

Search parameters

verbose: bool

Whether to print a detailed description

Implementations

Source

impl Identify

pub fn result<S>(&self, env: &mut Env<S>) -> (String, Vec<NotFound<'_>>)
where S: Fstat + GetCwd + IsExecutableFile + Sysconf + 'static,

Identifies the commands and returns the result.

This function returns a string that should be printed to the standard output, as well as a list of errors that should be printed to the standard error.

This function requires an instance of IsKeyword to be present in the environment’s any storage to check for keywords. If no such instance is found, this function will panic.

pub async fn execute<S>(&self, env: &mut Env<S>) -> Result
where S: Fcntl + Fstat + GetCwd + IsExecutableFile + Isatty + Sysconf + Write + 'static,

Performs the identifying semantics.