ConflictingOptionError

Struct ConflictingOptionError 

pub struct ConflictingOptionError<'a> { /* private fields */ }
Error indicating that two or more options conflict with each other

This is a helper object for constructing an error message from a list of conflicting option occurrences. An instance of this type can be created using new or pick_from_indexes and printed with report_error.

Implementations

Source

impl<'a> ConflictingOptionError<'a>

pub fn new<T: Into<Vec<OptionOccurrence<'a>>>>(options: T) -> Self

Creates a new ConflictingOptionError from a list of conflicting options.

The vector should contain at least two elements, or the returned error object may panic when formatted.

pub fn pick_from_indexes<const N: usize>( options: Vec<OptionOccurrence<'a>>, indexes: [usize; N], ) -> Self

Creates a new ConflictingOptionError with conflicting options extracted from a vector.

This function retains only the options in the vector whose indexes are specified in indexes. The other options are discarded.

The indexes may be specified in any order as they are sorted in this function.

indexes should contain at least two elements, or the returned error object may panic when formatted. This function panics immediately if indexes contains a duplicate index.

This function is useful for constructing a ConflictingOptionError from the result of parse_arguments. After examining the OptionOccurrence vector returned by the function, the caller can pick the indexes of the conflicting options and pass them to this function.

For example, calling ConflictingOptionError::pick_from_indexes(vec![a, b, c, d, e], [3, 0]) is equivalent to ConflictingOptionError::new([a, d]).

pub fn options(&self) -> &[OptionOccurrence<'a>]

Returns the list of conflicting options.

pub fn to_report(&'a self) -> Report<'a>

Converts this error into a report.