Mode

Struct Mode 

pub struct Mode { /* private fields */ }
Configuration for customizing the argument parsing behavior

Examples

The default configuration disables all non-portable extensions:

let mode = Mode::default();
assert!(!mode.accepts_long_options());

The with_extensions function returns a Mode with those extensions enabled.

let mode = Mode::with_extensions();
assert!(mode.accepts_long_options());

Implementations

Source

impl Mode

pub const fn with_extensions() -> Self

Returns a new Mode with non-portable extensions enabled.

pub fn with_env<S>(env: &Env<S>) -> Self

Convenience initializer

This function returns Self::default() or Self::with_extensions() depending on env.options.get(PosixlyCorrect).

pub const fn accepts_long_options(&self) -> bool

Whether the parser accepts long options or not

pub fn accept_long_options(&mut self, accept: bool) -> &mut Self

Sets whether the parser accepts long options or not.