#[non_exhaustive]pub struct OptionOccurrence<'a> {
pub spec: &'a OptionSpec<'a>,
pub location: Location,
pub argument: Option<Field>,
}Expand description
Occurrence of an option
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.spec: &'a OptionSpec<'a>Specification for this option
location: LocationLocation of the field containing this option
argument: Option<Field>Argument to this option
This value is always None for an option that does not take an argument.
This value always contains a field for an option that requires an argument.
If the option name and its argument are given in a single field, the field value is modified to contain only the option argument.