OptionSpec

Struct OptionSpec 

pub struct OptionSpec<'a> { /* private fields */ }
Specification of an option

This structure may contain the following properties:

  • Short option name (a single character)
  • Long option name (a string)
  • Whether this option takes an argument

All of these are optional, but either or both of the short and long names should be set for the option spec to have meaningful effect.

Implementations

Source

impl OptionSpec<'static>

pub const fn new() -> Self

Creates a new empty option spec.

Source

impl OptionSpec<'_>

pub const fn get_short(&self) -> Option<char>

Returns the short option name.

pub fn set_short(&mut self, name: char)

Gives a short name for this option.

The name should not be a hyphen.

pub const fn short(self, name: char) -> Self

Chained version of set_short

Source

impl<'a> OptionSpec<'a>

pub const fn get_long(&self) -> Option<&'a str>

Returns the long option name.

pub fn set_long(&mut self, name: &'a str)

Gives a long name for this option.

The name should not start with "--" or include "=".

pub const fn long(self, name: &'a str) -> Self

Chained version of set_long

Source

impl OptionSpec<'_>

pub const fn get_argument(&self) -> OptionArgumentSpec

Returns whether this option takes an argument.

pub fn set_argument(&mut self, argument: OptionArgumentSpec)

Specifies whether this option takes an argument.

pub const fn argument(self, argument: OptionArgumentSpec) -> Self

Chained version of set_argument