#[non_exhaustive]pub enum Error {
UnknownOption(Field),
ConflictingOptions {
signal_arg: Field,
list_option_name: char,
list_option_location: Location,
},
MissingSignal {
signal_option_name: char,
signal_option_location: Location,
},
MultipleSignals(Field, Field),
InvalidSignal(Field),
MissingTarget,
}Expand description
Error that may occur during parsing
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnknownOption(Field)
An argument starts with a hyphen (-) but is not a valid option.
ConflictingOptions
The signal to send is specified and the -l or -v option is also
specified.
Fields
MissingSignal
The -s or -n option is not followed by a signal name or number.
Fields
MultipleSignals(Field, Field)
More than one signal to send is specified.
InvalidSignal(Field)
A specified signal is not a valid signal name or number.
This error is returned when the argument to the -s or -n option is
not a valid signal name or number. This error also occurs when an
operand given with the -l or -v option is not a valid signal name,
signal number, or exit status.
MissingTarget
No target is specified and the -l or -v option is not specified.
Implementations