Command

Struct Command 

#[non_exhaustive]
pub struct Command { pub delimiter: u8, pub is_raw: bool, pub variables: Vec<Field>, pub last_variable: Field, }
Abstract command line arguments of the read built-in

An instance of this struct is created by parsing command line arguments using the syntax module.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
delimiter: u8

Delimiter specified by the -d option

When the option is not specified, this field is b'\n'.

is_raw: bool

Whether the -r option is specified

If this field is true, backslashes are not interpreted.

variables: Vec<Field>

Names of variables to be assigned, except the last one

last_variable: Field

Name of the last variable to be assigned

The last variable receives all remaining fields, including the intermediate (but not trailing) field separators.