Command

Enum Command 

pub enum Command {
    SetVariables(SetVariables),
    PrintVariables(PrintVariables),
    SetFunctions(SetFunctions),
    PrintFunctions(PrintFunctions),
}
Set of information that defines the behavior of a single invocation of the typeset built-in

The syntax::interpret function returns a value of this type after parsing the arguments. Call the execute method to perform the actual operation.

Variants



SetVariables(SetVariables)



PrintVariables(PrintVariables)



SetFunctions(SetFunctions)



PrintFunctions(PrintFunctions)

Implementations

Source

impl Command

pub fn execute<S>( self, env: &mut Env<S>, print_context: &PrintContext<'_>, ) -> Result<String, Vec<ExecuteError>>

Executes the command (except for actual printing).

This method updates the shell environment according to the command. If there are no errors, the method returns a string that should be printed to the standard output. Otherwise, the method returns a non-empty vector of errors.