UndoReadOnlyError

Struct UndoReadOnlyError 

pub struct UndoReadOnlyError {
    pub name: Field,
    pub read_only_location: Location,
}
Error that occurs when trying to cancel the read-only attribute of a variable or function

Fields

name: Field

Name of the variable or function

read_only_location: Location

Location where the variable or function was made read-only