#[non_exhaustive]pub enum InterpretError<'a> {
OptionInapplicableForFunction {
clashing: OptionOccurrence<'a>,
function: OptionOccurrence<'a>,
},
}Expand description
Error in interpreting command line arguments
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OptionInapplicableForFunction
Short option that cannot be used with the -f option
Fields

clashing: OptionOccurrence<'a>Occurrence of the option that conflicts with the -f option

function: OptionOccurrence<'a>Occurrence of the -f option
Implementations