ParseError

Enum ParseError 

#[non_exhaustive]
pub enum ParseError { UnknownShortOption(char, Field), UnknownLongOption(Field), AmbiguousLongOption(Field), UncancelableShortOption(char, Field), UncancelableLongOption(Field), }
Error in command line parsing

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnknownShortOption(char, Field)

Short option that is not defined in the option specs



UnknownLongOption(Field)

Long option that is not defined in the option specs



AmbiguousLongOption(Field)

Long option that matches the prefix of more than one option name.



UncancelableShortOption(char, Field)

Negated short option that is not an attribute



UncancelableLongOption(Field)

Negated long option that is not an attribute

Implementations

Source

impl ParseError

pub fn field(&self) -> &Field

Returns the field containing the option that caused this error.

pub fn to_report(&self) -> Report<'_>

Converts this error to a Report.