pub enum Error {
UnsupportedResource,
SoftLimitExceedsHardLimit,
NoPermissionToRaiseHardLimit,
Overflow,
Unknown(Errno),
}Expand description
Error that may occur in Command::execute
Variants
UnsupportedResource
The specified resource is not supported on the current platform.
SoftLimitExceedsHardLimit
The specified soft limit is greater than the hard limit.
NoPermissionToRaiseHardLimit
The new hard limit is greater than the current hard limit and the user does not have permission to raise the hard limit.
Overflow
The specified limit is out of range.
Unknown(Errno)
Other error