Command

Enum Command 

pub enum Command {
    Show {
        symbolic: bool,
    },
    Set(Vec<Clause>),
}
Interpretation of command-line arguments that determine the behavior of the umask built-in

Variants



Show

Show the current file mode creation mask

Fields

symbolic: bool


Set(Vec<Clause>)

Set the file mode creation mask

Implementations

Source

impl Command

pub fn set_from_raw_mask(mask: u16) -> Self

Creates a Command::Set variant from a raw mask.

This is a convenience method for creating a Command::Set variant from a raw mask. The result contains a single clause that sets the mask to the given value for all bits.

pub fn execute<S: Umask>(&self, env: &mut Env<S>) -> String

Executes the umask built-in.

Regardless of the command type, this function performs the following steps:

  1. Obtain the current mask from the environment. (Umask::umask)
  2. Compute a new mask to be set. (eval::new_mask)
  3. Set the new mask. (Umask::umask)

Returns the string that should be printed to the standard output.