pub enum Error {
NothingToWait,
Trapped(Number, Result),
SystemError(Errno),
}Expand description
Errors that may occur while waiting for a job
Variants
NothingToWait
There is no job to wait for.
Trapped(Number, Result)
The built-in was interrupted by a signal and the trap action was executed.
SystemError(Errno)
An unexpected error occurred in the underlying system.