pub struct Identify {
pub names: Vec<Field>,
pub search: Search,
pub verbose: bool,
}Expand description
Parameters to identify a utility
Fields
names: Vec<Field>Command names
search: SearchSearch parameters
verbose: boolWhether to print a detailed description
Implementations
Sourceimpl Identify
impl Identify
Sourcepub fn result<S>(&self, env: &mut Env<S>) -> (String, Vec<NotFound<'_>>)
pub fn result<S>(&self, env: &mut Env<S>) -> (String, Vec<NotFound<'_>>)
Identifies the commands and returns the result.
This function returns a string that should be printed to the standard output, as well as a list of errors that should be printed to the standard error.
This function requires an instance of IsKeyword to be present in the
environment’s any storage to check for keywords. If no
such instance is found, this function will panic.