pub struct OptionSpec<'a> { /* private fields */ }Expand description
Specification of an option
This structure may contain the following properties:
- Short option name (a single character)
- Long option name (a string)
- Whether this option takes an argument
All of these are optional, but either or both of the short and long names should be set for the option spec to have meaningful effect.
Implementations
Sourceimpl OptionSpec<'static>
impl OptionSpec<'static>
Sourceimpl OptionSpec<'_>
impl OptionSpec<'_>
Sourceimpl<'a> OptionSpec<'a>
impl<'a> OptionSpec<'a>
Sourceimpl OptionSpec<'_>
impl OptionSpec<'_>
Sourcepub const fn get_argument(&self) -> OptionArgumentSpec
pub const fn get_argument(&self) -> OptionArgumentSpec
Returns whether this option takes an argument.
Sourcepub fn set_argument(&mut self, argument: OptionArgumentSpec)
pub fn set_argument(&mut self, argument: OptionArgumentSpec)
Specifies whether this option takes an argument.
Sourcepub const fn argument(self, argument: OptionArgumentSpec) -> Self
pub const fn argument(self, argument: OptionArgumentSpec) -> Self
Chained version of set_argument