pub struct UndoReadOnlyError {
pub name: Field,
pub read_only_location: Location,
}Expand description
Error that occurs when trying to cancel the read-only attribute of a variable or function
Fields
name: FieldName of the variable or function
read_only_location: LocationLocation where the variable or function was made read-only