pub enum Command {
Show {
symbolic: bool,
},
Set(Vec<Clause>),
}Expand description
Interpretation of command-line arguments that determine the behavior of the
umask built-in
Variants
Implementations
Sourceimpl Command
impl Command
Sourcepub fn set_from_raw_mask(mask: u16) -> Self
pub fn set_from_raw_mask(mask: u16) -> Self
Creates a Command::Set variant from a raw mask.
This is a convenience method for creating a Command::Set variant from
a raw mask. The result contains a single clause that sets the mask to
the given value for all bits.
Sourcepub fn execute<S: Umask>(&self, env: &mut Env<S>) -> String
pub fn execute<S: Umask>(&self, env: &mut Env<S>) -> String
Executes the umask built-in.
Regardless of the command type, this function performs the following steps:
- Obtain the current mask from the environment. (
Umask::umask) - Compute a new mask to be set. (
eval::new_mask) - Set the new mask. (
Umask::umask)
Returns the string that should be printed to the standard output.